@@ -2,7 +2,7 @@ package Module::Install::XSUtil;
 
 use 5.005_03;
 
-$VERSION = '0.31';
+$VERSION = '0.32';
 
 use Module::Install::Base;
 @ISA     = qw(Module::Install::Base);
@@ -143,7 +143,7 @@ sub use_ppport{
 }
 
 sub use_xshelper {
-    my($self) = @_;
+    my($self, $opt) = @_;
     $self->_xs_initialize();
     $self->use_ppport();
 
@@ -151,8 +151,14 @@ sub use_xshelper {
     open my $fh, '>', $file or die "Cannot open $file for writing: $!";
     print $fh $self->_xshelper_h();
     close $fh or die "Cannot close $file: $!";
-
-    $self->clean_files($file);
+    if(defined $opt) {
+        if($opt eq '-clean') {
+            $self->clean_files($file);
+        }
+        else {
+            $self->realclean_files($file);
+        }
+    }
     return;
 }
 
@@ -611,6 +617,7 @@ sub cc_append_to_funclist{
 
 sub _xshelper_h {
     my $h = <<'XSHELPER_H';
+:/* THIS FILE IS AUTOMATICALLY GENERATED BY Module::Install::XSUtil $VERSION. */
 :/*
 :=head1 NAME
 :
@@ -712,6 +719,7 @@ sub _xshelper_h {
 :    } STMT_END
 XSHELPER_H
     $h =~ s/^://xmsg;
+    $h =~ s/\$VERSION\b/$Module::Install::XSUtil::VERSION/xms;
     return $h;
 }
 
@@ -757,7 +765,7 @@ Module::Install::XSUtil - Utility functions for XS modules
 
 =head1 VERSION
 
-This document describes Module::Install::XSUtil version 0.31.
+This document describes Module::Install::XSUtil version 0.32.
 
 =head1 SYNOPSIS
 
@@ -833,12 +841,15 @@ Creates F<ppport.h> using C<Devel::PPPort::WriteFile()>.
 This command calls C<< configure_requires 'Devel::PPPort' => $version >>
 and adds C<-DUSE_PPPORT> to C<MakeMaker>'s C<DEFINE>.
 
-=head2 use_xshelper
+=head2 use_xshelper ?-clean|-realclean
 
 Create sF<xshelper.h>, which is a helper header file to include
 F<EXTERN.h>, F<perl.h>, F<XSUB.h> and F<ppport.h>, and defines
 some portability stuff which are not supported by F<ppport.h>.
 
+Optional argument C<-clean> and C<-realclean> set C<clean_files>
+or C<realclean_files> to the generated file F<xshelper.h> respectably.
+
 This command includes C<use_ppport>.
 
 =head2 cc_warnings
